EmbyPy module
=============

.. automodule:: embypy

.. autosummary::
   Emby
   Emby.info
   Emby.search
   Emby.latest
   Emby.nextUp
   Emby.update
   Emby.albums
   Emby.create_playlist
   Emby.artists
   Emby.songs
   Emby.playlists
   Emby.episodes
   Emby.movies

.. autoclass:: Emby
   :members:
